Index: channels/chan_zap.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_zap.c,v
retrieving revision 1.327
diff -u -r1.327 chan_zap.c
--- channels/chan_zap.c	31 Aug 2004 00:08:52 -0000	1.327
+++ channels/chan_zap.c	31 Aug 2004 12:14:57 -0000
@@ -223,6 +223,8 @@
 static int cur_rxflash = -1;
 static int cur_debounce = -1;
 
+static int priindication_oob = 0;
+
 #ifdef ZAPATA_PRI
 static int minunused = 2;
 static int minidle = 0;
@@ -494,6 +496,7 @@
 	int busydetect;
 	int busycount;
 	int callprogress;
+	int priindication_oob;
 	struct timeval flashtime;	/* Last flash-hook time */
 	struct ast_dsp *dsp;
 	int cref;					/* Call reference number */
@@ -4135,7 +4138,12 @@
 	if (index == SUB_REAL) {
 		switch(condition) {
 		case AST_CONTROL_BUSY:
-			res = tone_zone_play_tone(p->subs[index].zfd, ZT_TONE_BUSY);
+#ifdef ZAPATA_PRI
+			if (p->priindication_oob && p->sig == SIG_PRI)
+				res = pri_hangup(p->pri->pri, p->call, PRI_CAUSE_USER_BUSY);
+			else
+#endif
+				res = tone_zone_play_tone(p->subs[index].zfd, ZT_TONE_BUSY);
 			break;
 		case AST_CONTROL_RINGING:
 #ifdef ZAPATA_PRI
@@ -4198,7 +4206,12 @@
 			break;
 		case AST_CONTROL_CONGESTION:
 			chan->hangupcause = AST_CAUSE_CONGESTION;
-			res = tone_zone_play_tone(p->subs[index].zfd, ZT_TONE_CONGESTION);
+#ifdef ZAPATA_PRI
+			if (p->priindication_oob && p->sig == SIG_PRI)
+				res = pri_hangup(p->pri->pri, p->call, PRI_CAUSE_SWITCH_CONGESTION);
+			else
+#endif
+				res = tone_zone_play_tone(p->subs[index].zfd, ZT_TONE_CONGESTION);
 			break;
 		case AST_CONTROL_RADIO_KEY:
 			if (p->radio) 
@@ -6132,6 +6145,8 @@
 		tmp->zaptrcallerid = zaptrcallerid;
 		tmp->restrictcid = restrictcid;
 		tmp->use_callingpres = use_callingpres;
+		tmp->priindication_oob = priindication_oob;
+
 		strncpy(tmp->accountcode, accountcode, sizeof(tmp->accountcode)-1);
 		tmp->amaflags = amaflags;
 		if (!here) {
@@ -9107,6 +9122,11 @@
                                ast_log(LOG_WARNING, "Unknown network-specific facility '%s'\n", v->value);
                                nsf = PRI_NSF_NONE;
                        }
+	        } else if (!strcasecmp(v->name, "priindication")) {
+			if (!strcasecmp(v->value, "outofband"))
+				priindication_oob = 1;
+			else
+				priindication_oob = 0;
 		} else if (!strcasecmp(v->name, "minunused")) {
 			minunused = atoi(v->value);
 		} else if (!strcasecmp(v->name, "idleext")) {
Index: configs/zapata.conf.sample
===================================================================
RCS file: /usr/cvsroot/asterisk/configs/zapata.conf.sample,v
retrieving revision 1.28
diff -u -r1.28 zapata.conf.sample
--- configs/zapata.conf.sample	17 Jul 2004 01:30:43 -0000	1.28
+++ configs/zapata.conf.sample	31 Aug 2004 12:14:57 -0000
@@ -80,6 +80,14 @@
 ;
 ;overlapdial=yes
 ;
+; PRI Out of band indications.
+; Enable this to report Busy and Congestion on a PRI using out-of-band
+; notification. Inband indication, as used by Asterisk doesn't seem to work
+; with all telcos.
+;
+; priindication = outofband
+;
+;
 ; Signalling method (default is fxs).  Valid values:
 ; em:      E & M
 ; em_w:    E & M Wink
